#ifndef _GENERAL_UTILITY_METHODS_H_
#define _GENERAL_UTILITY_METHODS_H_

/**************************************************************************
* Copyright (c) 2007
* Computer Aided Interventions and Medical Robotics (CAIMR) group,
* Imaging Science and Information Systems (ISIS) research center,
* Georgetown University.
*
* All rights reserved.
*
* Permission to use, copy, modify, distribute, and sell this software
* and its documentation for any purpose is hereby granted without fee,
* provided that:
* (1) Redistributions of source code must retain the above copyright notice,
*     this list of conditions and the following disclaimer.
* (2) Redistributions in binary form must reproduce the above copyright notice,
*     this list of conditions and the following disclaimer in the documentation
*      and/or other materials provided with the distribution.
* (3) The author's name may not be used to endorse or promote products derived
*     from this software without specific prior written permission.
* (4) Modified source versions must be plainly marked as such, and must not be
*     misrepresented as being the original software.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER ``AS IS'' AND ANY EXPRESS
* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
* OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
* WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
* OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
**************************************************************************/

#include <string>
#include <sstream>

/**
 * General utility methods that do not belong to a specific class.
 *
 * @author Ziv Yaniv
 */
namespace GeneralUtilityMethods {

/**
 * Convert a string into a double.
 * If the string contains characters that are not part of a number the method will throw a runtime_error.
 */
double Atof(const std::string &str) throw (std::runtime_error)
{
  char *ptr;
  double value = strtod(str.c_str(),&ptr);
  if(*ptr!='\0') //end of double data isn't the NULL character
    throw std::runtime_error("Conversion of std::string to double failed.");
  return value;
}

/**
 * Convert a string into a long int.
 * If the string contains characters that are not part of a number the method will throw a runtime_error.
 */
long Atoi(const std::string &str) throw (std::runtime_error)
{
  char *ptr;
  long value = strtol(str.c_str(),&ptr,10);
  if(*ptr!='\0') //end of double data isn't the NULL character
    throw std::runtime_error("Conversion of std::string to long failed.");
  return value;
}


} //end namespace GeneralUtilityMethods

#endif //_GENERAL_UTILITY_METHODS_H_
